@@ -13,6 +13,8 @@ __all__ = (
 
 import warnings
 
+from urllib.request import urlopen
+
 try:
     # requests is an optional dependency; we can provide better error messages
     # when we know that it's unavailable before a user attempts a web request
@@ -154,6 +156,7 @@ from .familyfoodonthetable import FamilyfoodOnTheTable
 from .farmhousedelivery import FarmhouseDelivery
 from .farmhouseonboone import FarmhouseOnBoone
 from .fattoincasadabenedetta import FattoInCasaDaBenedetta
+from .feastingathome import FeastingAtHome
 from .felixkitchen import FelixKitchen
 from .fifteengram import FifteenGram
 from .fifteenspatulas import FifteenSpatulas
@@ -354,6 +357,7 @@ from .saboresajinomoto import SaboresAjinomoto
 from .sallysbakingaddiction import SallysBakingAddiction
 from .sallysblog import SallysBlog
 from .saltpepperskillet import SaltPepperSkillet
+from .samsungfood import SamsungFood
 from .sandwhichtribunal import SandwhichTribunal
 from .saveur import Saveur
 from .savorynothings import SavoryNothings
@@ -372,6 +376,7 @@ from .southerncastiron import SouthernCastIron
 from .southernliving import SouthernLiving
 from .spainonafork import SpainOnAFork
 from .spendwithpennies import SpendWithPennies
+from .spisbedre import SpisBedre
 from .springlane import Springlane
 from .stacyling import StacyLing
 from .staysnatched import StaySnatched
@@ -406,6 +411,7 @@ from .themediterranedish import TheMediterraneDish
 from .themodernproper import TheModernProper
 from .thepalatablelife import ThePalatableLife
 from .thepioneerwoman import ThePioneerWoman
+from .theplantbasedschool import ThePlantBasedSchool
 from .therecipecritic import Therecipecritic
 from .thesaltymarshmallow import TheSaltyMarshmallow
 from .thespruceeats import TheSpruceEats
@@ -464,6 +470,7 @@ SCRAPERS = {
     AfghanKitchenRecipes.host(): AfghanKitchenRecipes,
     AkisPetretzikis.host(): AkisPetretzikis,
     AlbertHeijn.host(): AlbertHeijn,
+    AlbertHeijn.host(domain="ah.be"): AlbertHeijn,
     Aldi.host(): Aldi,
     AldiNord.host(): AldiNord,
     AldiNord.host(domain="aldi.es"): AldiNord,
@@ -567,6 +574,7 @@ SCRAPERS = {
     ElaVegan.host(): ElaVegan,
     EvolvingTable.host(): EvolvingTable,
     FamilyfoodOnTheTable.host(): FamilyfoodOnTheTable,
+    FeastingAtHome.host(): FeastingAtHome,
     FifteenGram.host(): FifteenGram,
     FitSlowCookerQueen.host(): FitSlowCookerQueen,
     FortyAprons.host(): FortyAprons,
@@ -629,10 +637,12 @@ SCRAPERS = {
     Rewe.host(): Rewe,
     RecipeLand.host(): RecipeLand,
     RicettePerBimby.host(): RicettePerBimby,
+    SamsungFood.host(): SamsungFood,
     SandwhichTribunal.host(): SandwhichTribunal,
     SavoryNothings.host(): SavoryNothings,
     SheLikesFood.host(): SheLikesFood,
     SpainOnAFork.host(): SpainOnAFork,
+    SpisBedre.host(): SpisBedre,
     StacyLing.host(): StacyLing,
     StrongrFastr.host(): StrongrFastr,
     SugarHero.host(): SugarHero,
@@ -644,6 +654,7 @@ SCRAPERS = {
     TheLoopyWhisk.host(): TheLoopyWhisk,
     TheMediterraneDish.host(): TheMediterraneDish,
     ThePalatableLife.host(): ThePalatableLife,
+    ThePlantBasedSchool.host(): ThePlantBasedSchool,
     TheSaltyMarshmallow.host(): TheSaltyMarshmallow,
     Thinlicious.host(): Thinlicious,
     DomesticateMe.host(): DomesticateMe,
@@ -1011,3 +1022,8 @@ def scrape_html(
         return schema_scraper
 
     raise NoSchemaFoundInWildMode(org_url)
+
+
+def scrape_me(url: str) -> AbstractScraper:
+    html = urlopen(url).read().decode("utf-8")
+    return scrape_html(html, org_url=url)
