@@ -1,5 +1,5 @@
-# mypy: disallow_untyped_defs=False
 from ._abstract import AbstractScraper
+from ._exceptions import StaticValueException
 from ._utils import get_minutes, get_yields, normalize_string
 
 
@@ -8,6 +8,9 @@ class PaniniHappy(AbstractScraper):
     def host(cls):
         return "paninihappy.com"
 
+    def site_name(self):
+        raise StaticValueException(return_value="Panini Happy®")
+
     def title(self):
         return self.soup.find("h1", {"class": "entry-title"}).get_text()
 
