@@ -1,5 +1,5 @@
-# mypy: disallow_untyped_defs=False
 from ._abstract import AbstractScraper
+from ._exceptions import StaticValueException
 from ._utils import normalize_string
 
 
@@ -11,6 +11,14 @@ class TastyKitchen(AbstractScraper):
     def title(self):
         return self.soup.find("h1", {"itemprop": "name"}).get_text()
 
+    def site_name(self):
+        current_selection = next(
+            iter(self.soup.select("div.tpw-network a.selected")), None
+        )
+        if not current_selection:
+            raise StaticValueException(return_value="Tasty Kitchen")
+        return current_selection.text
+
     def ingredients(self):
         ingredients = self.soup.find("ul", {"class": "ingredients"}).findAll("li")
 
