@@ -34,6 +34,6 @@ class UitPaulinesKeukenNL(AbstractScraper):
         return normalize_string(
             self.soup.find("article", {"class": "single-recipe"})
             .findChild("section", {"class": "text"})
-            .find_next()
+            .find_next(name=True)
             .get_text()
         )
